diff --git a/src/backend/executor/nodeAppend.c b/src/backend/executor/nodeAppend.c
index 1fc55e90d7..d67abed330 100644
--- a/src/backend/executor/nodeAppend.c
+++ b/src/backend/executor/nodeAppend.c
@@ -61,6 +61,7 @@
 #include "executor/execPartition.h"
 #include "executor/nodeAppend.h"
 #include "miscadmin.h"
+#include "optimizer/cost.h"
 
 /* Shared state for parallel-aware Append. */
 struct ParallelAppendState
@@ -128,8 +129,12 @@ ExecInitAppend(Append *node, EState *estate, int eflags)
 	/* Let choose_next_subplan_* function handle setting the first subplan */
 	appendstate->as_whichplan = INVALID_SUBPLAN_INDEX;
 
-	/* If run-time partition pruning is enabled, then set that up now */
-	if (node->part_prune_info != NULL)
+	/*
+	 * If run-time partition pruning is enabled, then set that up now.
+	 * However, enable_partition_pruning may have been turned off since when
+	 * the plan was created, so recheck its value.
+	 */
+	if (node->part_prune_info != NULL && enable_partition_pruning)
 	{
 		PartitionPruneState *prunestate;
 
diff --git a/src/backend/executor/nodeMergeAppend.c b/src/backend/executor/nodeMergeAppend.c
index c7eb18e546..5252930b17 100644
--- a/src/backend/executor/nodeMergeAppend.c
+++ b/src/backend/executor/nodeMergeAppend.c
@@ -43,6 +43,7 @@
 #include "executor/nodeMergeAppend.h"
 #include "lib/binaryheap.h"
 #include "miscadmin.h"
+#include "optimizer/cost.h"
 
 /*
  * We have one slot for each item in the heap array.  We use SlotNumber
@@ -89,8 +90,12 @@ ExecInitMergeAppend(MergeAppend *node, EState *estate, int eflags)
 	mergestate->ps.ExecProcNode = ExecMergeAppend;
 	mergestate->ms_noopscan = false;
 
-	/* If run-time partition pruning is enabled, then set that up now */
-	if (node->part_prune_info != NULL)
+	/*
+	 * If run-time partition pruning is enabled, then set that up now.
+	 * However, enable_partition_pruning may have been turned off since when
+	 * the plan was created, so recheck its value.
+	 */
+	if (node->part_prune_info != NULL && enable_partition_pruning)
 	{
 		PartitionPruneState *prunestate;
 
